==> haskell-math-functions-0.1.5.2-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-math-functions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: math-functions
version: 0.1.5.2
id: math-functions-0.1.5.2-86b215538bcdb4d98c1408b77b7af726
key: mathf_0AMfOnjcGx30LUTgHOMLGp
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/math-functions
synopsis: Special functions and Chebyshev polynomials
description:
    This library provides implementations of special mathematical
    functions and Chebyshev polynomials.  These functions are often
    useful in statistical and numerical computing.
category: Math, Numeric
author: Bryan O'\''Sullivan <bos@serpentine.com>,
        Aleksey Khudyakov <alexey.skladnoy@gmail.com>
exposed: True
exposed-modules:
    Numeric.MathFunctions.Constants Numeric.Polynomial
    Numeric.Polynomial.Chebyshev Numeric.SpecFunctions
    Numeric.SpecFunctions.Extra Numeric.Sum
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/math-functions-0.1.5.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/math-functions-0.1.5.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/math-functions-0.1.5.2
hs-libraries: HSmath-functions-0.1.5.2-0AMfOnjcGx30LUTgHOMLGp
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    erf-2.0.0.0-aab48415b057e47fae23d9f8b194cc70
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    vector-th-unbox-0.2.1.3-e9e43f819592d04fe0a37fca65bc4268
haddock-interfaces: /usr/share/doc/haskell-math-functions/html/math-functions.haddock
haddock-html: /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-math-functions-0.1.5.2-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-math-functions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: math-functions
version: 0.1.5.2
id: math-functions-0.1.5.2-cca3e664aeca2116145d4ae702f767c6
key: mathf_A9DHuwO2BZXLLz4oXGAjY0
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/math-functions
synopsis: Special functions and Chebyshev polynomials
description:
    This library provides implementations of special mathematical
    functions and Chebyshev polynomials.  These functions are often
    useful in statistical and numerical computing.
category: Math, Numeric
author: Bryan O'\''Sullivan <bos@serpentine.com>,
        Aleksey Khudyakov <alexey.skladnoy@gmail.com>
exposed: True
exposed-modules:
    Numeric.MathFunctions.Constants Numeric.Polynomial
    Numeric.Polynomial.Chebyshev Numeric.SpecFunctions
    Numeric.SpecFunctions.Extra Numeric.Sum
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/math-functions-0.1.5.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/math-functions-0.1.5.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/math-functions-0.1.5.2
hs-libraries: HSmath-functions-0.1.5.2-A9DHuwO2BZXLLz4oXGAjY0
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    erf-2.0.0.0-aab48415b057e47fae23d9f8b194cc70
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    vector-th-unbox-0.2.1.4-1139d5b6f0cb29dac6aff26bf8525b7e
haddock-interfaces: /usr/share/doc/haskell-math-functions/html/math-functions.haddock
haddock-html: /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
